==> sugarcrm-6.2.1.tbz: www/sugarcrm/modules/History/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

 


$mod_strings = array (
  'LBL_MODULE_NAME' => 'History',
  'LBL_MODULE_TITLE' => 'History: Home',
  'LBL_SEARCH_FORM_TITLE' => 'History Search',
  'LBL_LIST_FORM_TITLE' => 'History',
  'LBL_LIST_SUBJECT' => 'Subject',
  'LBL_LIST_CONTACT' => 'Contact',
  'LBL_LIST_RELATED_TO' => 'Related to',
  'LBL_LIST_DATE' => 'Date',
  'LBL_LIST_TIME' => 'Start Time',
  'LBL_LIST_CLOSE' => 'Close',
  'LBL_SUBJECT' => 'Subject:',
  'LBL_STATUS' => 'Status:',
  'LBL_LOCATION' => 'Location:',
  'LBL_DATE_TIME' => 'Start Date & Time:',
  'LBL_DATE' => 'Start Date:',
  'LBL_TIME' => 'Start Time:',
  'LBL_DURATION' => 'Duration:',
  'LBL_HOURS_MINS' => '(hours/minutes)',
  'LBL_CONTACT_NAME' => 'Contact Name: ',
  'LBL_MEETING' => 'Meeting:',
  'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
  'LBL_DESCRIPTION' => 'Description:',
  'LBL_COLON' => ':',
  'LBL_DEFAULT_STATUS' => 'Planned',
  'LNK_NEW_CALL' => 'Log Call',
  'LNK_NEW_MEETING' => 'Schedule Meeting',
  'LNK_NEW_TASK' => 'Create Task',
  'LNK_NEW_NOTE' => 'Create Note or Attachment',
  'LNK_NEW_EMAIL' => 'Archive Email',
  'LNK_CALL_LIST' => 'Calls',
  'LNK_MEETING_LIST' => 'Meetings',
  'LNK_TASK_LIST' => 'Tasks',
  'LNK_NOTE_LIST' => 'Notes',
  'LNK_EMAIL_LIST' => 'Emails',
  'ERR_DELETE_RECORD' => 'A record number must be specified to delete the account.',
  'NTC_REMOVE_INVITEE' => 'Are you sure you want to remove this invitee from the meeting?',
  'LBL_INVITEE' => 'Invitees',
  'LBL_LIST_DIRECTION' => 'Direction',
  'LBL_DIRECTION' => 'Direction',
  'LNK_NEW_APPOINTMENT' => 'New Appointment',
  'LNK_VIEW_CALENDAR' => 'Today',
  'LBL_OPEN_ACTIVITIES' => 'Open Activities',
  'LBL_HISTORY' => 'History',
  'LBL_UPCOMING' => 'My Upcoming Appointments',
  'LBL_TODAY' => 'through ',
  'LBL_NEW_TASK_BUTTON_TITLE' => 'Create Task [Alt+N]',
  'LBL_NEW_TASK_BUTTON_KEY' => 'N',
  'LBL_NEW_TASK_BUTTON_LABEL' => 'Create Task',
  'LBL_SCHEDULE_MEETING_BUTTON_TITLE' => 'Schedule Meeting [Alt+M]',
  'LBL_SCHEDULE_MEETING_BUTTON_KEY' => 'M',
  'LBL_SCHEDULE_MEETING_BUTTON_LABEL' => 'Schedule Meeting',
  'LBL_SCHEDULE_CALL_BUTTON_TITLE' => 'Log Call [Alt+C]',
  'LBL_SCHEDULE_CALL_BUTTON_KEY' => 'C',
  'LBL_SCHEDULE_CALL_BUTTON_LABEL' => 'Log Call',
  'LBL_NEW_NOTE_BUTTON_TITLE' => 'Create Note or Attachment [Alt+T]',
  'LBL_NEW_NOTE_BUTTON_KEY' => 'T',
  'LBL_NEW_NOTE_BUTTON_LABEL' => 'Create Note or Attachment',
  'LBL_TRACK_EMAIL_BUTTON_TITLE' => 'Archive Email [Alt+K]',
  'LBL_TRACK_EMAIL_BUTTON_KEY' => 'K',
  'LBL_TRACK_EMAIL_BUTTON_LABEL' => 'Archive Email',
  'LBL_LIST_STATUS' => 'Status',
  'LBL_LIST_DUE_DATE' => 'Due Date',
  'LBL_LIST_LAST_MODIFIED' => 'Last Modified',
  'NTC_NONE_SCHEDULED' => 'None scheduled.',
  'appointment_filter_dom' => array(
  	 'today' => 'today'
  	,'tomorrow' => 'tomorrow'
  	,'this Saturday' => 'this week'
  	,'next Saturday' => 'next week'
  	,'last this_month' => 'this month'
  	,'last next_month' => 'next month'
  ),
  'LNK_IMPORT_NOTES'=>'Import Notes',
  'NTC_NONE'=>'None',
	'LBL_ACCEPT_THIS'=>'Accept?',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'History',
);

?>

==> sugarcrm-6.5.6.tbz: www/sugarcrm/modules/History/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2012 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

 


$mod_strings = array (
  'LBL_MODULE_NAME' => 'History',
  'LBL_MODULE_TITLE' => 'History: Home',
  'LBL_SEARCH_FORM_TITLE' => 'History Search',
  'LBL_LIST_FORM_TITLE' => 'History',
  'LBL_LIST_SUBJECT' => 'Subject',
  'LBL_LIST_CONTACT' => 'Contact',
  'LBL_LIST_RELATED_TO' => 'Related to',
  'LBL_LIST_DATE' => 'Date',
  'LBL_LIST_TIME' => 'Start Time',
  'LBL_LIST_CLOSE' => 'Close',
  'LBL_SUBJECT' => 'Subject:',
  'LBL_STATUS' => 'Status:',
  'LBL_LOCATION' => 'Location:',
  'LBL_DATE_TIME' => 'Start Date & Time:',
  'LBL_DATE' => 'Start Date:',
  'LBL_TIME' => 'Start Time:',
  'LBL_DURATION' => 'Duration:',
  'LBL_HOURS_MINS' => '(hours/minutes)',
  'LBL_CONTACT_NAME' => 'Contact Name: ',
  'LBL_MEETING' => 'Meeting:',
  'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
  'LBL_DESCRIPTION' => 'Description:',
  'LBL_COLON' => ':',
  'LBL_DEFAULT_STATUS' => 'Planned',
  'LNK_NEW_CALL' => 'Log Call',
  'LNK_NEW_MEETING' => 'Schedule Meeting',
  'LNK_NEW_TASK' => 'Create Task',
  'LNK_NEW_NOTE' => 'Create Note or Attachment',
  'LNK_NEW_EMAIL' => 'Archive Email',
  'LNK_CALL_LIST' => 'Calls',
  'LNK_MEETING_LIST' => 'Meetings',
  'LNK_TASK_LIST' => 'Tasks',
  'LNK_NOTE_LIST' => 'Notes',
  'LNK_EMAIL_LIST' => 'Emails',
  'ERR_DELETE_RECORD' => 'A record number must be specified to delete the account.',
  'NTC_REMOVE_INVITEE' => 'Are you sure you want to remove this invitee from the meeting?',
  'LBL_INVITEE' => 'Invitees',
  'LBL_LIST_DIRECTION' => 'Direction',
  'LBL_DIRECTION' => 'Direction',
  'LNK_NEW_APPOINTMENT' => 'New Appointment',
  'LNK_VIEW_CALENDAR' => 'Today',
  'LBL_OPEN_ACTIVITIES' => 'Open Activities',
  'LBL_HISTORY' => 'History',
  'LBL_UPCOMING' => 'My Upcoming Appointments',
  'LBL_TODAY' => 'through ',
  'LBL_NEW_TASK_BUTTON_TITLE' => 'Create Task',
  'LBL_NEW_TASK_BUTTON_KEY' => 'N',
  'LBL_NEW_TASK_BUTTON_LABEL' => 'Create Task',
  'LBL_SCHEDULE_MEETING_BUTTON_TITLE' => 'Schedule Meeting',
  'LBL_SCHEDULE_MEETING_BUTTON_KEY' => 'M',
  'LBL_SCHEDULE_MEETING_BUTTON_LABEL' => 'Schedule Meeting',
  'LBL_SCHEDULE_CALL_BUTTON_TITLE' => 'Log Call',
  'LBL_SCHEDULE_CALL_BUTTON_KEY' => 'C',
  'LBL_SCHEDULE_CALL_BUTTON_LABEL' => 'Log Call',
  'LBL_NEW_NOTE_BUTTON_TITLE' => 'Create Note or Attachment',
  'LBL_NEW_NOTE_BUTTON_KEY' => 'T',
  'LBL_NEW_NOTE_BUTTON_LABEL' => 'Create Note or Attachment',
  'LBL_TRACK_EMAIL_BUTTON_TITLE' => 'Archive Email',
  'LBL_TRACK_EMAIL_BUTTON_KEY' => 'K',
  'LBL_TRACK_EMAIL_BUTTON_LABEL' => 'Archive Email',
  'LBL_LIST_STATUS' => 'Status',
  'LBL_LIST_DUE_DATE' => 'Due Date',
  'LBL_LIST_LAST_MODIFIED' => 'Last Modified',
  'NTC_NONE_SCHEDULED' => 'None scheduled.',
  'appointment_filter_dom' => array(
  	 'today' => 'today'
  	,'tomorrow' => 'tomorrow'
  	,'this Saturday' => 'this week'
  	,'next Saturday' => 'next week'
  	,'last this_month' => 'this month'
  	,'last next_month' => 'next month'
  ),
  'LNK_IMPORT_NOTES'=>'Import Notes',
  'NTC_NONE'=>'None',
	'LBL_ACCEPT_THIS'=>'Accept?',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'History',
);

?>
